package com.jdblabs.timestamper.gui.plugin;

import java.io.File;
import java.util.Map;
import com.jdblabs.timestamper.core.TimelineMarker;

public interface TimestamperPlugin {

    /**
     * Called before the GUI loads a new timeline properties file. This method
     * allows you to perform an action before a timeline properties file is
     * loaded, or to change the file that will be loaded by returning a new
     * File object.
     * @param mainMVC Map of the model, view, and controller objects for the
     *  timestamper main GUI.
     * @param propertyFile The file that will be loaded.
     * @return The property file to load (often the same as the one passed in)
     */
    File onTimelineLoad(Map<String, Object> mainMVC, File propertyFile);

    /**
     * Called after the GUI is initialized but before it is displayed.
     * @param mainMVC map of the model, view, and controller objects for the
     *  timestamper main GUI.
     */
    void onStartup(Map<String, Object> mainMVC);

    /**
     * Called before the GUI exits. This is a best-attempt call, since the OS
     * may force-terminate the application before it has a chance to be called.
     * Long-running operations should not be performed in this call, as some
     * OSes may impatiently terminate the application if it thinks it has hung.
     * @param mainMVC map of the model, view, and controller objects for the
     *  timestamper main GUI.
     */
    void onExit(Map<String, Object> mainMVC);

    /**
     * Called before the GUI adds a new marker to the timeline.
     * This allows you to perform some action when a new marker is created,
     * modify the marker, or return an entirely new marker.
     * @param mainMVC map of the model, view, and controller objects for the
     *  timestamper main GUI.
     * @param newMarker The new TimelineMarker to be added to the timeline.
     * @return The timeline marker to add to the timeline (often the same
     *  marker passed in).
     */
    TimelineMarker onNewTask(Map<String, Object> mainMVC, TimelineMarker newMarker);

    /**
    * Called before the GUI deletes a marker from the timeline. 
     * @param mainMVC map of the model, view, and controller objects for the
     *  timestamper main GUI.
     * @param marker The TimelineMarker to be deleted.
     */
    void onDeleteTask(Map<String, Object> mainMVC, TimelineMarker marker);
}
