package com.jdblabs.timestamper.gui.plugin

import com.jdblabs.timestamper.core.TimelineMarker
import org.jivesoftware.smack.ConnectionConfiguration
import org.jivesoftware.smack.XMPPConnection
import org.jivesoftware.smack.packet.Presence
import org.slf4j.Logger
import org.slf4j.LoggerFactory

public class XMPPStatusUpdater implements TimestamperPlugin {

    XMPPConnection conn
    private Logger logger = LoggerFactory.getLogger(getClass())

    public void onStartup(Map mainMVC) {

        logger.trace("Starting XMPPStatusUpdater plugin")

        String server = mainMVC.model.config."xmpp.server"
        int port = mainMVC.model.config.getProperty("xmpp.port", 5222)
        String username = mainMVC.model.config."xmpp.username"
        String password = mainMVC.model.config."xmpp.password"
        
        try {
            conn = new XMPPConnection(new ConnectionConfiguration(server, port))
            conn.connect()
            conn.login(username, password, "timestamper-xmpp-plugin")
        } catch (Exception e) {
            logger.error("Unable to initialize XMPPUpdater.", e)
            conn = null
        }
    }

    public void onExit(Map mainMVC) {
        logger.trace("Stopping XMPPStatusUpdater plugin")
        
        try { conn.disconnect() } catch (Exception e) {}
    }

    public File onTimelineLoad(Map mainMVC, File propFile) {}

    public TimelineMarker onNewTask(Map mainMVC, TimelineMarker newTask) {
        if (!conn) {
            logger.info("XMPPStatusUpdater is not initialized, " +
                "skipping onNewTask()")
            return newTask
        }

        logger.trace("Setting XMPP presence based on new task: {}", newTask)

        conn.sendPacket(new Presence(Presence.Type.available, newTask.mark,
            0, Presence.Mode.available))
    }

    public void onDeleteTask(Map mainMVC, TimelineMarker task) {}
}
